Unreleased changes
------------------

* Remove template artifacts


Version 0
---------
0.3.0 / 2020-11-05
~~~~~~~~~~~~~~~~~~
* OscProb ``oscillationsprobabilities`` now takes PDG IDs as input and also
  accepts scalars and arrays for each input (flavor in, flavour out, energies
  and cos_zeniths)

0.2.0 / 2020-10-29
~~~~~~~~~~~~~~~~~~
* First prototype of OscProb wrapper

0.1.0 / 2020-10-28
~~~~~~~~~~~~~~~~~~
* Project generated using the cookiecutter template from
  https://git.km3net.de/templates/python-project
